menu
accessibility_provider package
documentation
classes/audio_cue.dart
AudioCue class
AudioCue class
dark_mode
light_mode
AudioCue
class
Constructors
AudioCue
({
String
url
=
''
,
Uint8List
?
bytes
,
required
String
name
})
Properties
bytes
→
Uint8List
?
final
hashCode
→
int
The hash code for this object.
no setter
inherited
name
→
String
final
runtimeType
→
Type
A representation of the runtime type of the object.
no setter
inherited
url
→
String
final
Methods
copyWith
(
{
String
?
id
,
String
?
name
,
String
?
url
,
Uint8List
?
bytes
})
→
AudioCue
noSuchMethod
(
Invocation
invocation
)
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson
(
)
→
Map
<
String
,
dynamic
>
toString
(
)
→
String
A string representation of this object.
inherited
Operators
operator ==
(
Object
other
)
→
bool
The equality operator.
inherited
Static Methods
fromJson
(
Map
<
String
,
dynamic
>
json
)
→
AudioCue
accessibility_provider package
documentation
classes/audio_cue
AudioCue class
audio_cue library